| covdepGE-package | R Documentation |
A covariate-dependent approach to Gaussian graphical modeling as described in Dasgupta et al. (2022). Employs a novel weighted pseudo-likelihood approach to model the conditional dependence structure of data as a continuous function of an extraneous covariate. The main function, covdepGE::covdepGE(), estimates a graphical representation of the conditional dependence structure via a block mean-field variational approximation, while several auxiliary functions (inclusionCurve(), matViz(), and plot.covdepGE()) are included for visualizing the resulting estimates.
Maintainer: Jacob Helwig jacob.a.helwig@tamu.edu
Authors:
Sutanoy Dasgupta sutanoy@stat.tamu.edu
Peng Zhao pzhao@stat.tamu.edu
Bani Mallick bmallick@stat.tamu.edu
Debdeep Pati debdeep@stat.tamu.edu
(1) Sutanoy Dasgupta, Peng Zhao, Prasenjit Ghosh, Debdeep Pati, and Bani Mallick. An approximate Bayesian approach to covariate-dependent graphical modeling. pages 1–59, 2022.
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.